#
# spec file for package carla
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1501
%bcond_without liblo
%else
%bcond_with liblo
%endif

%define __provides_exclude_from ^%{_libdir}/carla/jack/.*.so.0$
Name:           carla
#NOTE: to update this package please change these two version fields in "_service" <param name="revision">v2.1.1</param>
# to the version that you want and execute "osc service runall"
# It will even fill in the .changes file. Please don't touch the Version: in the spec file, it will be filled automaticaly.
Version:        2.5.2
Release:        bp155.1.6
Summary:        An audio plugin host
License:        BSD-2-Clause AND GPL-2.0-or-later AND BSD-3-Clause
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://kx.studio/Applications:Carla
Source0:        %{name}-%{version}.tar.xz
Source1:        carla-warning
Source2:        bsd-2-clause.txt
# PATCH-FIX-OPENSUSE -- Use system flac/vorbis/ogg
Patch0:         0001-Use-system-flac-vorbis-ogg.patch
# PATCH-FIX-OPENSUSE -- Remove rpath from .pc files davejplater@gmail.com
Patch1:         0002-Remove-rpath-from-.pc-files.patch
# PATCH-FIX-OPENSUSE -- Use the correct plugin paths for openSUSE sflees@suse.de
Patch2:         0003-Use-correct-plugin-paths-for-openSUSE.patch
BuildRequires:  fdupes
BuildRequires:  file-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-qtbase-devel
# for extra native plugins
BuildRequires:  non-ntk-fluid
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  python3-qt5-devel
BuildRequires:  python3-rdflib
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
# for extra samplers support
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(gl)
# for plugin GUIs
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
%if %{with liblo}
BuildRequires:  pkgconfig(liblo)
%endif
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(mxml)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(zlib)
#Wine
#!BuildIgnore:  sane-backends-32bit
BuildRequires:  freetype2-devel-32bit
BuildRequires:  gcc-32bit
BuildRequires:  gcc-c++-32bit
BuildRequires:  glibc-devel-32bit glibc-32bit
BuildRequires:  libX11-devel-32bit
BuildRequires:  libXcursor-devel-32bit
BuildRequires:  libXext-devel-32bit
BuildRequires:  libstdc++-devel-32bit
%if 0%{?suse_version} >= 1550
BuildRequires:  mingw32-cross-gcc
BuildRequires:  mingw32-cross-gcc-c++
BuildRequires:  mingw64-cross-gcc
BuildRequires:  mingw64-cross-gcc-c++
BuildRequires:  wine
BuildRequires:  wine-devel
BuildRequires:  wine-devel-32bit
Suggests:       %{name}-vst = %{version}
%endif
#End wine
Requires:       python3-base
Requires:       python3-qt5
Requires:       python3-rdflib
%if %{with liblo}
Requires:       python3-pyliblo
%endif
ExclusiveArch:  x86_64

%description
Carla is an audio plugin host, with support for many audio drivers
and plugin formats. It features automation of parameters via MIDI CC
and full OSC control. It currently supports LADSPA, DSSI, LV2, VST2/3
and AU plugin formats, plus GIG, SF2 and SFZ sounds banks.
It futher supports bridging Window plugins using Wine.

%package devel
Summary:        Header files to access Carla's API
Group:          Development/Libraries/C and C++
Requires:       carla = %{version}
Requires:       pkgconfig

%description devel
This package contains header files needed when writing software using
Carla's several APIs.

%package vst
Summary:        CarlaRack and CarlaPatchbay VST plugins
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name} = %{version}

%description vst
This package contanis Carla VST plugins, including CarlaPatchbayFX,
CarlaPatchbay, CarlaRackFX, and CarlaRack. It also contains the
win32 and wine32 binaries for handling ms win32 vst plugins

%prep
%autosetup -p1
#for i in `grep -rl "/usr/bin/env python3"`;do $(sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i}; chmod +x ${i}) ;done

%build
#remove -m64 from the build
%define optflags -O2 -Wall -D_FORTIFY_SOURCE=2 -funwind-tables -fasynchronous-unwind-tables -Werror=return-type -flto=auto
export CXXFLAGS="%{optflags}"
export CFLAGS="%{optflags}"

# list build configuration, no need for optflags or -j
make features

make %{_smp_mflags} \
%ifnarch %{ix86} x86_64
	BASE_OPTS= \
%endif
	--trace
#Makes 32bit plugin capabilities
make posix32
#missing /usr/lib64/gcc/i686-w64-mingw32/9.2.0/libssp.a
%if 0%{?suse_version} >= 1550
export CFLAGS=`echo $CFLAGS | sed s/\-flto=auto//`
export CXXFLAGS=`echo $CXXFLAGS | sed s/\-flto=auto//`
echo $CFLAGS
echo $CXXFLAGS
make --trace win32 CC=i686-w64-mingw32-gcc CXX=i686-w64-mingw32-g++ LIBDIR=%{_libdir} CFLAGS="$CFLAGS" CXXFLAGS="$CXXFLAGS" LDFLAGS="-Wl,--no-insert-timestamp"
make --trace win64 CC=x86_64-w64-mingw32-gcc CXX=x86_64-w64-mingw32-g++ LIBDIR=%{_libdir} CFLAGS="$CFLAGS" CXXFLAGS="$CXXFLAGS" LDFLAGS="-Wl,--no-insert-timestamp"
make --trace wine32 LIBDIR=%{_libdir} CFLAGS="$CFLAGS" CXXFLAGS="$CXXFLAGS" LDFLAGS="-L/usr/lib/wine"
make --trace wine64 LIBDIR=%{_libdir} CFLAGS="$CFLAGS" CXXFLAGS="$CXXFLAGS" LDFLAGS="-L%{_libdir}/wine"
%endif

%install
make install DESTDIR=%{buildroot} PREFIX="%{_prefix}" LIBDIR="%{_libdir}"

pushd %{buildroot}
for i in `grep -rl "/usr/bin/env python"`;do $(sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i}; chmod +x ${i}) ;done
for i in `grep -rl "/usr/bin/env python3"`;do $(sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i}; chmod +x ${i}) ;done
for i in `grep -rl "/usr/bin/python3"`;do chmod +x ${i} ;done
popd

cp -v source/modules/lilv/serd-0.24.0/tests/TurtleTests/LICENSE LICENSE.TurtleTests

# Cadence uses carla_util.py which also uses carla_backend.py so they need to be in pythonsitelib
mkdir -p %{buildroot}/%{python3_sitelib}
pushd %{buildroot}/%{python3_sitelib}
ln -rs %{buildroot}%{_datadir}/carla/carla_backend.py .
ln -rs %{buildroot}%{_datadir}/carla/carla_utils.py .
popd

# SUSE specific
%if 0%{?suse_version}
 %suse_update_desktop_file -r carla AudioVideo Music
 %if %{with liblo}
 %suse_update_desktop_file -r carla-control AudioVideo Music
 %endif
 %fdupes -s %{buildroot}%{_datadir}
 %fdupes -s %{buildroot}%{_includedir}
%endif
mkdir -p %{buildroot}%{_localstatedir}/adm/update-messages/
#%%{name}-warning
cp %{S:1}  %{buildroot}%{_localstatedir}/adm/update-messages/
cp %{S:2} .

%files
%license doc/GPL.txt doc/LGPL.txt LICENSE.TurtleTests bsd-2-clause.txt
%doc README.md doc/Carla-TestCases
%{_bindir}/*
%{_libdir}/carla
%exclude %{_libdir}/carla/carla-bridge-posix32
%exclude %{_libdir}/carla/carla-discovery-posix32
%if 0%{?suse_version} >= 1550
%exclude %{_libdir}/carla/carla-bridge-win32.exe
%exclude %{_libdir}/carla/carla-bridge-win64.exe
%exclude %{_libdir}/carla/carla-discovery-win32.exe
%exclude %{_libdir}/carla/carla-discovery-win64.exe
%exclude %{_libdir}/carla/jackbridge-wine32.dll
%exclude %{_libdir}/carla/jackbridge-wine64.dll
%endif
%dir %{_libdir}/lv2
%{_libdir}/lv2/carla.lv2
%{_datadir}/carla
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/mime/packages/carla.xml
%{_datadir}/appdata/studio.kx.carla.appdata.xml
%{python3_sitelib}/carla*.py
%{_localstatedir}/adm/update-messages/%{name}-warning

%post
cat %{_localstatedir}/adm/update-messages/%{name}-warning

%files vst
%dir %{_libdir}/vst
%{_libdir}/vst/carla.vst
%{_libdir}/carla/carla-bridge-posix32
%{_libdir}/carla/carla-discovery-posix32
%if 0%{?suse_version} >= 1550
%{_libdir}/carla/carla-bridge-win32.exe
%{_libdir}/carla/carla-bridge-win64.exe
%{_libdir}/carla/carla-discovery-win32.exe
%{_libdir}/carla/carla-discovery-win64.exe
%{_libdir}/carla/jackbridge-wine32.dll
%{_libdir}/carla/jackbridge-wine64.dll
%endif

%files devel
%{_includedir}/carla
%{_libdir}/pkgconfig/*

%changelog
* Sat Jan  7 2023 mia@0x0.st
- Update to version 2.5.2:
  * Improve debug messages
  * Correct jackbridge build flags
  * LTO must not be used for building wine stuff (not just linking)
  * Also prevent -flto from wine link flags
  * Prevent -static-lib{gcc,stdc++} flags from going to winelib stuff
  * Use LIB_EXT for wine libs copying
  * Bump version to 2.5.2
  * fix pkgconfig files having bad includedir/libdir variables
  * Revert "outer frame for carla-lv2" stuff, make it verbose instead
  * Import fixes from main branch into hotfix-2.5 one
- Refresh/Git format patches:
  * carla-systemlibs.patch
  - > 0001-Use-system-flac-vorbis-ogg.patch
  * carla-remove-pkgconf-rpath.patch
  - > 0002-Remove-rpath-from-.pc-files.patch
  * use-correct-plugin-paths.patch
  - > 0003-Use-correct-plugin-paths-for-openSUSE.patch
* Mon Oct 10 2022 christophe@krop.fr
- Update to version 2.5.1:
  * Force usage of i686-w64-mingw32 for win32 builds on 64bit systems
  * Restore positions of external patchbay graph nodes
  * Adjust for JUCE MIDI API changes, fix external MIDI connections
  * Correct last commit, ensure ysfx uses generic approach for wasm
  * Ignore MIDI ports known to cause issues in JUCE engine
  * Change default driver on windows from DirectSound to Windows Audio
  * Ignore some compiler warnings from qt side
  * Fix logic around engine driver listings
  * Use an outer frame for carla-lv2 outgoing events
  * Fix a small leak
  * Fix free/delete[] misusage
  * Make malloc usage consistent in CarlaString class
  * Cleanup ysfx setup
  * Fully remove water::Variant use
  * Stop using NamedValueSet in AudioProcessorGraph
  * Do not set scale factor for LV2 plugin UIs on macOS
  * Bump version to 2.5.1
  * Fix several race conditions
  * Use generic implementation for ysfx eel riscv builds
  * Correct last commit
  * Alternative approach for systems without MAP_LOCKED (build&runtime)
  * Math utils performance tweaks
  * Set X11 utf8 window title for plugin UIs
  * noop: remove trailing whitespace
  * Fix build with older SDL2
  * Fix typo
  * Fix build with new wine
  * Make sure SDL is disabled for static plugin target
  * Add missing file
  * Update included DPF
  * Fix not building static binaries on windows (2.5.0 regression)
  * Fix win32 CI stuff
  * Make ysfx compatible with FreeBSD
  * Add #if defined(__FreeBSD__) to avoid #include <alloca.h> on FreeBSD
  * Try to fix i386 build
- Enable support for Win64 VST
- Update build requirements
* Fri Sep 30 2022 ecsos@opensuse.org
- Update to version 2.5.0:
  * Update copyright information related to JUCE
  * Update juce plugin time related code for new APIs
  * Another python3.10 compat fix
  * Expose through backend API hints which plugin UIs are file based
  * Do not use wine in CI builds if we can skip it
  * Dont use LTO for windows CI builds for now
  * Fix win32 builds
  * Bump version to 2.5.0
  * Fix windows/mingw build
  * Fix strict build
  * Fix macOS build
  * Use full driver settings dialog in engine menu if not running
  * Fix macOS build
  * Update to JUCE 7.0.1, still to update to new playhead APIs
  * Update included DPF
  * Simplify wasm runner, using emscripten_set_interval
  * Adjust to the non-threaded usage
  * Also block sem_timedwait usage
  * Make sure no threads are used on wasm
  * Disable audiofile ops debug on wasm, verified to work
  * Set default LV2 path for emscripten
  * Add missing opus as supported extension in audio file plugin
  * Report plugin UI close in embed mode
  * Link DGL against CoreVideo on macOS
  * Use emscripten_set_timeout_loop instead of manual management
  * water: Add back a way to get win appdata and programfiles
  * Cleanup
  * Really fix build, unless compiler crashes..
  * Another build fix
  * Fix a typo
  * Ignore pthread_yield for now
  * Set _FILE_OFFSET_BITS=64 for ysfx
  * Fix windows build
  * Fix build after latest changes
  * One more build fix
  * Fix regular build
  * Reenable audiofile seeking on wasm, which works now
  * Do not allow to use capture logging thread on wasm
  * Bring Runner class from DPF, use it for Engine background details
  * More tweaks for wasm, engine verified to work, still with hacks
  * Do not enable pthreads for wasm builds
  * Update dgl and distrho modules
  * Dont use simd for wasm just yet, fix missing APP_EXT usage
  * Dont strip wasm binaries, cleanup
  * Fix make clean
  * More tweaks for wasm and sdl
  * Add SDL/wasm test code
  * Fix SDL engine for SDL1, work wasm workarounds
  * Allow to disable JACK, and skip bridges for wasm
  * AudioFileReader: workarounds for wasm non-threaded behaviour
  * CarlaThread: Ignore a few things for wasm usage
  * Initial SDL engine implementation
  * emscripten related tweaks
  * Keep VST3 hosting through JUCE, for now
  * Rework and cleanup makefiles, add WASM var
  * Allow to build with custom DGL namespace
  * ysfx build tweaks as needed for armhf and MOD builds
  * Fix water::DirectoryIterator for windows builds
  * Fix a typo
  * Another attempt at fixing ARM build
  * Support mod:volts as LV2 unit
  * Start handling VST3 events
  * A few vst3 host fixes, no longer crash on load
  * Tweak about/features for vst3 usage without juce
  * Hacky juce test code for investigating vst3 keyboard input
  * Add some stubs to vst3 host code
  * Fix the previous armhf fix
  * Start python level automated tests, WIP
  * Make macOS installer allowed to install without rosetta2
  * Another armhf fix
  * Alternative approach to fix armhf builds
  * Allow to link against custom DPF/DGL
  * Fix armhf (non-aarch64) build
  * Correction for ysfx %%progbits
  * Make sure to not export ysfx symbols
  * Another small change needed for ysfx on arm
  * Fix external plugins submodule, was changed by mistake
  * Reorder makefile static plugin target rules
  * Add -fsigned-char to ysfx flags
  * Fix non-linux build
  * Fix 32bit build and some warnings
  * Fix ysfx no-gui build
  * Update ysfx
  * Fix wine plugin build
  * Cleanup for CARLA_DECLARE_NON_COPYABLE macro use, minor jsfx things
  * Disable juce usage on non mac/win builds
  * Fix DISTRHO_UI_FILE_BROWSER usage
  * Allow to build internal plugins with a custom dpf
  * More tweaks needed for macOS builds
  * Tweaks to get external dpf plugins to build together
  * Allow DGL in static builds
  * Fix a typo
  * Fix macOS build
  * Build fixes
  * Initial code for juce-less VST3 native hosting
  * Do not use -fno-gnu-unique on BSD
  * Do not export extra DllMain for extra internal windows plugins
  * Tweak HAVE_YSFXGUI files
  * Fix linux build
  * Add new file needed for updated dpf
  * Fix a typo
  * Cleanup some ysfx things and fix guiless build
  * Adjust jsfx things to changes in Carla internals
  * Fix debug build
  * Skip msys2 CI builds that broke for no reason
  * macOS build fix, tested this time
  * Try to build less juce stuff
  * Disable JUCE Dxgi usage incompatible with older mingw
  * Update juce
  * Yet another approach
  * Alternative macOS fix
  * Fix macOS build
  * Really fix windows build
  * Calculate Io count properly
  * Fix a leak
  * Fix windows build
  * Implement native vst3 plugin scanning; Cleanup
  * Cleanup some discovery stuff
  * Continue cleanup
  * More cleanup
  * Cleanup
  * Start cleaning up the water
  * Remove use of WATER_COMPILER_SUPPORTS_MOVE_SEMANTICS Was never properly supported, and causes crashes in a few places
  * Only use -std=gnu++14 when building for juce
  * Build a few more files in c++14 for macOS
  * Fix use of USE_COREGRAPHICS_RENDERING macro
  * Another macOS fix
  * Add missing files
  * Update DPF
  * Make juce config read by all files
  * Keep old mingw32 tweaks to workaround crash in juce_audio_basics
  * Fix macOS build
  * Fix windows build with juce
  * Fix juce mingw issues
  * Fix new code carla for plugin bridge use
  * Always build juce_gui_extra; Add new mingw std compat files
  * Delete temporary files added by mistake
  * Start the update to JUCE7
  * Mention JSFX support in help text
  * Link fontconfig in the 32-bit bridge build
  * Implement JSFX (frontend)
  * Implement JSFX (backend)
  * Add ysfx (upstream 60917c4)
- Rebase carla-systemlibs.patch.
- Drop fix-include-array.patch because can no more applied.
* Fri Sep 30 2022 ecsos@opensuse.org
- Update to version 2.4.4:
  * Bump version
  * Another python3.10 compat fix
  * Do not use -fno-gnu-unique on BSD
  * Support mod:volts as LV2 unit
  * Fix water::DirectoryIterator for windows builds
  * Fix make clean
  * Skip msys2 CI builds that broke for no reason
  * Fix external plugins build with mxml >= 3.0
  * Fix macOS build
  * Fix inaccurate midi CC rounding (#1612)
  * juce never links against x11
  * Update dependency list
* Sat Jun  4 2022 ecsos <ecsos@opensuse.org>
- Add fix-include-array.patch to fix Tumbleweed build error.
* Tue Apr 26 2022 rpm@fthiessen.de
- Update to version 2.4.3:
  * Fix integration with internal Qt toolbar visibility state
  * Fix plugin search
  * Replace CARLA_EXPORT macro with separate API / PLUGIN export options
  * Set new X-NSM-Exec desktop file property
* Sat Feb 26 2022 edogawa@aon.at
- refactored carla-remove-pkgconf-rpath.patch (changed file paths)
- Update to version 2.4.2:
  * FIx old macOS build
  * Fix build with old macOS
  * Fix strict build
  * And another one
  * Another int/float python fix
  * Fix Haiku build
  * Haiku cannot use -pthread
  * Do not error out when including AppConfig.h
  * Adjust the rest of the code for CARLA_BACKEND_NAMESPACE macro use
  * macOS plugin UI fixes
  * Allow custom carla namespace, useful for static builds
  * Fix compat with old pyqt
  * Fix make clean for STATIC_PLUGIN_TARGET
  * One more XSetInputFocus exception fix
  * Do not use RT threads for dummy engine / plugin testing
  * Fix a memory leak in the CarlaString class
  * Use gcc built-in expect to speed up safe asserts
  * Move second image to it's own screenshot tag
  * FreeBSD patch in AppConfig.h
  * Update external plugins submodule
  * Reload audio file if sample rate changes
  * Correct the offset used in the custom data restore fix
  * Update copyright year for the modified files
  * Use temporary files for big custom data values in bridges
  * Ensure custom data restore is exactly how it was saved Fixes #1521
  * interposer: More debug, remove superfulous check causing crashes
  * Ignore JACK applications trying to handle MIDI when it is disabled
  * Add "[carla]" prefix to printed messages directly by carla Closes #1498
  * Fix crash when LV2 X11 UI has non-mapped child window Closes #1486
  * Fix strict build
  * Notify of embed resizes on bridges
  * Initial implementation for embedding UIs of bridged plugins
  * lv2: mark port as sidechain if part of a sidechain group
  * Add audio port hints to backend, starting with lv2 sidechain
  * Give notice when carla needs to be restarted after lv2 rescan
  * Revert "See if wine32 CI test passes"
  * See if wine32 CI test passes
  * Fix up CI
  * Prevent an assertion on dummy backend test
  * Bump version to 2.4.2
  * Add water::MemoryInputStream
  * Add PLUGIN_JSFX definition, not yet implemented
  * clarify carla_patchbay_connect() docs
  * Fix type error in signal emission
  * Fix "-n" switch with newer python
  * Fix bridge build Closes #1558
  * add CV32 variant with 64 audio ins/outs and 32 cv ins/outs
  * Implement dry/wet, volume and balance on juce hosted plugins
  * Add stubs for custom vst3 hosting
  * Cast QDial value parameter to prevent type error
  * Fixed unexpected type errors
  * Place zyn deps in STATIC_CARLA_PLUGIN_LIBS as needed
  * Update gitignore
  * Define ulonglong type
  * Define CUSTOM_DATA_TYPE_PATH and allow it for LV2 as custom data
  * Use -posix to build under mingw
  * Remove unused function
  * fix default sf2/3 path
  * default to jack backend if pipewire jack replacement is installed
  * Move pkgconfig files to their own dir, tweak and install appdata
  * add app metainfo (#1535)
  * Automable is not a word, sorry!
  * Skip JACK-applications as plugin in static plugin target builds
  * Look for directories too when searching non-found vst3 plugins
  * Add static-plugin target, fix some warnings
  * Do not use -ffat-lto-objects
  * Remove <br> from Windows readme.
  * Expose a 8cv carla patchbay variant
  * Yet another fix
  * Fix previous commit
  * Passing build flags in linker stage is required for LTO to work
  * Fix LTO build
  * Do not export DllMain for STATIC_PLUGIN_TARGET builds
  * Add WITH_LTO build option, disabled by default
  * Stop using old gnu++0x, switch to gnu++11
  * Disable GraphicsScene indexing method to prevent crashes
  * vst3: user common files in the default path
  * Fix dependency target for jackbridge
* Sun Oct 17 2021 ecsos@opensuse.org
- Update to version 2.4.1:
  * Don't expose symbols for STATIC_PLUGIN_TARGET
  * Fix STATIC_PLUGIN_TARGET build
  * Bump version to 2.4.1
  * Fix MemoryOutputStream destructor after the latest changes
  * Fix a strict compiler warning
  * explicit casting start
  * Install CarlaNativePlugin.h
  * Add NATIVE_PLUGIN_OPCODE_HOST_USES_EMBED, for special hosts
  * Update LV2 UI parameter values after embedding
  * Add STATIC_PLUGIN_TARGET macro; Fix wrong memory reads on lv2 list
  * Tweaks for Ildaeil, MemoryOutputStream::getDataAndRelease()
  * Correct last commit
  * Add carla_get_plugin_latency host function
  * More USING_RTAUDIO setup, build jackbridge.min.a
  * Start using USING_RTAUDIO macro
  * Lead by example
  * Separate system and dependency checks to new file
  * Safer way to fetch X11 UI size
  * Revert "Same fix for removeInternal"
  * Set PLUGIN_HAS_CUSTOM_EMBED_UI flag for LV2 plugins as possible
  * Fix build with some libraries in custom prefixes
  * Makefile user variables
  * Replace -lpthread with -pthread
  * Send keyboard and focus events to VST3 UIs as needed
  * Say hello to IRC :)
  * Fix unused parameters preventing real ones showing up
  * Fetch/set some extra info for VST3 plugin parameters
  * Import travesty files and rename a file
  * Fix VST3 cleanup order, component should be last
  * Use pthread_attr_setdetachstate when RT thread fails too
  * Start threads in detached state instead of calling detach
  * Check for valid x11 display before using it
  * CI: Add a few more linux build deps
  * Update external plugins, fixing static memory leak
  * Same fix for removeInternal
  * Fix misuse of water Arrays
  * Update README.md
  * Install header CarlaPluginPtr.hpp
  * Cleanup
  * Fix a compiler warning
  * Automatically close bridges if main Carla dies, macOS edition
  * Pass keyboard events to vst2 plugins in win/macOS
  * Do not set scale factor for vst2 native implementation under macOS
  * Make XY-Controller lines less think, close with Esc
  * Fix xy-controller GUI now possible to show on "make install" target
  * Ship lv2 gtk bridges with win/mac
  * Alternative approach to finding qt5 package for make dist
- Rebase carla-systemlibs.patch.
* Sat Aug 21 2021 ecsos@opensuse.org
- Update to version 2.4.0:
  * Remove a warning when libsndfile is not present (dr_mp3 still used)
  * One more CI fix
  * One more compiler warning fix
  * Fix some compiler warnings
  * Implement carla_get_desktop_scale_factor for X11
  * Bump version to 2.4.0
  * Add a few more packages to CI
  * One more CI fix
  * CI fixes
  * CI tweaks
  * Use WINECC env var in CI
  * Fix CI links and a typo
  * Adjust lv2 gtk ui bridge for windows
  * Add wine CI workflow
  * Add option to use classic skin by default
  * Speed up msys2-i686
  * Revert "less deps for msys2"
  * Revert "Give up on msys2 on CI"
  * Don't build static binaries on Windows if using msys2
  * Fix last commit
  * Don't require gobject/glib for gtk bridges, always enabled
  * Give up on msys2 on CI
  * Fix for custom gtk widgets, need to use global namespace
  * Fix build
  * Allow lv2 gtk bridges on any system
  * lv2 ui bridges: dlopen gtk instead of linking to it
  * less deps for msys2
  * Try adding pkg-config
  * Install a few things for msys2
  * Tweaks to msys2
  * More packaging tests, add msys2 types
  * Tweak build, still testing
  * Consolidate CI builds on single file
  * Fix macOS build and bridge standalone init
  * Set scale factor for carla-bridge-*/carla-single standalone usage
  * Fetch desktop scale factor for UI bridge testing; Cleanup
  * Redo canvas.svg in a way that scales with Qt
  * Replace canvas.png with svg version
  * Add carla_get_desktop_scale_factor utility function
  * Do not set JUCE editor scale factor under macOS
  * Import Linux-VST3 crash fix from upstream
  * Tweak for latest DPF compat
* Tue Aug 10 2021 ecsos@opensuse.org
- Update to version 2.3.2:
  * Bump version to 2.3.2
  * Dynamic version for pkg-config files, for less maintenance
  * Add 32x32 icon Fixes #1327
  * Fix an assertion
  * Fix strict build
  * Fix macOS build
  * Add macos plugin standalone init, fixing focus
  * Fix a typo on XSetInputFocus
  * Implement a way to set plugins as standalones
  * Add missing separator in SF2 search path
  * Fix a memory leak in CarlaString class
  * Do not show --gdb in usage/help when not installed system-wide Closes #1454
  * Rename a variable to make more sense
  * Safer X11 UI use, fixes crash with a few plugins (regression)
  * Ignore handleCommandMessage/postCommandMessage not used in linux
  * Fix wine32 build on Fedora Closes #1449
  * Fix X11 error when showing VST3 on linux
  * Add VST2 host embed support (native implementation)
- Rebase patches.
* Mon Jul 19 2021 ecsos@opensuse.org
- Update to version 2.3.1:
  * Add dmg files to gitignore
  * Also specify NSLocalNetworkUsageDescription
  * Set NSMicrophoneUsageDescription in Carla.plist
  * Bump version to 2.3.1
  * Fix build
  * Fix race condition around postponed rt event data pool
  * No wine stuff for now
  * Create macos-latest.yml
  * Tweak GH dependencies
  * Create GH action
  * Rename a variable
  * Handle LV2 UI size on windows without extensions, also resize
  * Do not refresh canvas except on error, fixing on quit crash
  * Finish updating juce deprecated API stuff
  * Fix loading state via juce of vst2 plugins without chunk
  * Update plugin juce code to new APIs, hook into vst2 for parity
  * Cleanup macOS plugin UI setup code, still fails at resizing :(
  * Fix build with JACKBRIDGE_DIRECT=true
  * Use tick_double on jack transport
  * Fix windows build
  * Fix wine build
  * Really fix split/join
  * Fix strict build
  * Make some macOS dialogs modal, hack around edit dialog on top
  * Improve countDecimalPoints
  * midipattern: always kill all notes on reposition
  * Fix default rack "skin" for a few plugins
  * Remove a useless variable
  * Fix bridged plugin UIs appearing behind main carla window on macOS
  * Use posix_spawn to launch macOS bridges
  * Strip macOS binaries
  * Use posix_spawn for macOS bridge mode scanning
  * Do not use 64bit int or long double for midi plugin playback
  * Remove favorite plugins from list when they fail to load
  * Fix canvas split/join action
  * splitted is not a word
  * Fix Qt version checks, allow canvas eyecandy for >= qt5.12
  * Fix initial size for LV2 macOS UIs with no UI resize extension
  * Fix a compiler warning
  * CI tweaks
  * More CI tweaks
  * Try fixing CI
  * Implement parameter groups for VST2 plugins (carla implementation)
  * Use our metadata thread-safe mutex for the new check, seems to work
  * Not so smart handling for now, jack2 meta-data is finicky..
  * One more fix
  * Alternative approach to deal with jack postponed events Might fix pipewire for real now, needs testing
  * Revert "React to jack callbacks as fast as possible, fixing pipewire usage"
  * Carla-VST: Ignore hosts calling effOpen twice, dont print error
  * Fix carla-vst-wine symbol visibility
  * Fix strict build
  * Listen to X11 plugin UI resize events automatically
  * Give keyboard focus to X11 plugin UIs
  * Do not set jack latency callbacks, we do nothing with them
  * Use _M_ARM64 macro to set win64 mode
  * One more assertion ignored for jack metadata/uuid
  * React to jack callbacks as fast as possible, fixing pipewire usage Closes #1348
  * Fix build with GCC11 Closes #1396
- Rebase patches.
- Drop fix-build-with-gcc11.patch, because now in upstream.
* Fri Jul  9 2021 Ben Greiner <code@bnavigator.de>
- Fix the Python script symlinks: in SLE/Leap, %%python_sitelib is
  empty if python2 is not installed. You want python3_sitelib.
* Mon May 31 2021 Simon Lees <sflees@suse.de>
- Use correct plugin paths for openSUSE (/usr/lib64/*)
  * use-correct-plugin-paths.patch
- Cadence uses carla_util.py which also uses carla_backend.py
  so add these to pythonsitelib
- Fix gcc-11 build
  * fix-build-with-gcc11.patch
- Add carla-host-plugin.pc to carla-remove-pkgconf-rpath.patch
* Fri Apr 23 2021 ecsos@opensuse.org
- Update to version 2.3.0:
  * Fix build
  * Fix carla-single/standalone-bridges not having default options enabled
  * Use .0 suffix for packaged files
  * Bump version as 2.3.0
  * Fix main client name for multiple carlas inside NSM Closes #1279
  * Do not run 2nd instance of lv2 plugin if it has event output(s) Fixes #1350
  * Tentative fix for missing vst3 poly aftertouch
  * Use fixed buffers on standalone bridge mode
  * Whitespace cleanup
  * midipattern: use Esc key to close UI
  * midipattern; kill note on event removal
  * Cleanup midi pattern UI event handling, 2/2
  * CarlaNative.h: move extern "C" after the includes to fix clang/libc++
  * Cleanup midi pattern UI event handling, 1/2
  * pianoroll: set cursor depending on hover action
  * Fix cancelling plugin discovery Closes #1391
  * Add .kdev_include_paths files
  * patchcanvas: clear rubberband on right-click
  * patchcanvas: stop storing keyboard modifier state, cleanup
  * Fix sorting plugins by favorite Closes #1390
  * Fix a typo
  * Make sure to ignore CCs above 120
  * Read lv2 midi:binding on control ports and parameters
  * Set project filename/folder before saving, not after
  * Fix a float vs int usage, which will break in python soon
  * Fix recursive VST2 audioMasterAutomate parameter changes Fixes #1365
  * Use Ctrl+P to open/close side panel Fixes #1193
  * Fix strict build
  * Bump version
  * audio_decoder: assume 16bit for encoded libsndfile files
  * Accept oga and opus audio files
  * Update static lv2 bundle too
  * Small tweaks in preparation of future things
  * Add num tracks info to midifile
  * audiofile: tweaks to "waveform" preview
  * midifile: make sure to start new files at frame 0
  * Fix a typo
  * Update midi file static lv2 bundle data
  * midifile: add repeat mode and make host-sync optional
  * audiofile: only advance internal frame if there is a file
  * Update static data of audiofile
  * audiofile: add host sync, enable and volume parameters
  * Fix wine bridge build for certain systems
  * Fix (native) plugin discovery under Windows
  * Fix plugin search listing AU as possible type on Windows
  * Fix a compiler warning
  * Fix loading project with vst3 plugin bridges
  * Ship with magic.mgc file on macOS
  * Setup CARLA_MAGIC_FILE env var for cxfreeze builds
  * Tweaks to make dist
  * Debug output of bridging vsts
  * Package 32bit bridges on macos non-universal builds
  * Use -universal suffix for macos-universal dmgs
  * Update FUNDING.yml
  * Update copyright year in about page
  * Fix logic around gCarla.nogui
  * Rework some CarlaString methods to prevent stack overflow
  * Silence cxfreeze stdout
  * Add FUNDING.yml
  * Specify mp3 file support on "make features"
  * Mention dr_mp3, libsndfile and zita-resampler in about page
  * Bump version
  * CLeanup
  * Fix make dist for windows
  * macOS arm64/x64 handling of VST3 plugins
  * Fix some compiler warnings
  * audiofile mp3: calculate seek points when loading file
  * Prevent issues with hosts sending MIDI events where they shouldnt
  * audiofile mp3: disable SIMD for macos-old builds
  * Fix typo
  * Fix pool fix calc, ignore wrap since it is too hard
  * Remove audiofile global init
  * Alternative mp3 handling via dr_mp3
  * Fetch bitrate and pool fill for audiofile
  * Read mp3 files on RAM
  * Small missing definition
  * audiofile: better use of local vs internal pool
  * Fix make dist for old mingw
  * Fix make dist plugin rules
  * Add win32 binaries to win64 packaging
  * Fix windows bridge build
  * more make dist tweaks
  * Finalize make dist for windows
  * Fix bridges build
  * Reduce excessive prints
  * Fully delete embed lv2 ui window on hide Fixes #1339
  * Fix assertion on empty project path; Change cwd of plugin bridges
  * 2 more icons
  * win32 make dist mostly works now
  * More tweaks for win32 make dist
  * Fix showing UI bridges for a few systems
  * Fix windows native tools, now without symlinks
  * Ignore irrelevant assertion when quitting windows bridge
  * Move some code around
  * Fix use of patchbay external canvas client with no plugins
  * Fix strict build
  * Fix some compiler warnings
  * Add cursor position to audiofile
  * Generate file preview for bigger files too
  * send audiofile preview as lv2 vector
  * audiofile: protect against race conditions when loading new files
  * audiofile: fix resampling of full loaded file
  * Try 30s for full audio file in ram
  * carla-lv2: only ask for "idle" one at a time
  * Smaller pool for audio file, but load full if < 10s; use mlock
  * MIDI file length, WIP
  * Fixup audiofile plugin for offline rendering
  * Start work for new windows toolchain build
  * Add a few more desktop-theme icon definitions
  * Support lv2 parameters that are both readable and writable
  * Fix mod fileTypes in lv2 audio/midi file plugins
  * Ignore priority increase warnings when testing plugins
  * Fix install with cross-compiling without lv2 plugin
  * Give up with BINARY_* expose, alternative approach
  * Try to fix strict build
  * expose binary types as macros so they can be compared to BINARY_NATIVE
  * Fix wine bridges build
  * Do not show custom GUI is testing plugins
  * Use carla-bridge-native.exe for native arch bridge on windows
  * Minor tweaks as used for testing
  * Fix previous commit
  * Do not build external plugins by default
  * Fix cross-compilation without an exe wrapper
  * Yet another old macOS build fix
  * Fix build on old macOS
  * Fix windows build
  * Reduce bridge plugin test to 5s
  * Allow to run CV plugins in rack mode, CV connects to dummy port
  * Clear PID when child process ends
  * Fix usage of empty filenames and labels for plugin bridges
  * Fix carla-control, regression from previous commits
  * Fix crash on internal vst handling with bad macOS plugins
  * Fix debug console output to be readable on macOS dark theme
  * Show description for carla-plugins pkg
  * Another makefile fix
  * Create macOS dmg on make dist
  * Remove old macOS data files
  * Fix make install, more make dist work
  * continue make dist cleanup
  * Rename a file to prevent possible recursion issues
  * make dist tweaks, now more generic
  * Initial work for system icons
  * Use proper carla-control icon in some systems
  * Add carla-control to make dist
  * Split off some makefile stuff into new files
  * Create carla app bundle in "make dist" command
  * Better way to find qt5 prefix on macOS for theme build
  * Now fix new compilers too :P
  * Force-fix macos theme builds
  * Fix build on macOS 10.5
  * Fix build on macOS 10.8
  * Rework state path support in carla lv2 plugins
  * Order lv2 parameters by URI
  * Catch lv2 dsp->ui messages, and prevent recursion from carla
  * Expose inline-display in carla lv2 plugins
  * Map NATIVE_HOST_OPCODE_REQUEST_IDLE to lv2 worker
  * Update pre-exported lv2-bundles to match latest changes
  * Fix old compilers build
  * Ammend previous commit
  * Fix lv2-bundles build
  * audiofile: Bail out if resample fails, whitespace cleanup
  * Fix strict build
  * Fix missing audio outputs in rack mode juce engine driver
  * audiofile: add some info as parameter outputs
  * Fix build with old compilers
  * audiofile: reduce lock time and use a spinlock as guard
  * audiofile: use host idle to read file, instead of custom thread
  * bigmeter: do not request inline display during process
  * audiofile: do not request inline display during process
  * Finish resampling details, seems to work nicely
  * On the fly resampling for audiofile
  * Initial tests with resampler
  * Add zita-resampler, to be used for audiofile
  * Start trying to package for osx nicely
  * Rough way of discoverying x64-only vsts on arm64 macOS
  * Save/restore side panel visiblity for carla-control
  * Remove custom return host on carla-control, no longer needed
  * Silent a pylint warning
  * Cleanup, fix offset in previous commit (OSC method)
  * Really fix/ignore client name if known host
  * Adjust static lv2 bundles for latest MOD file spec
  * Ignore client name if OSC message is from known host
  * Clear up situation with nogui and carla-osc-gui script
  * Workaround buggy lo_address_get_port
  * Cleanup some OSC message size
  * Use OSC message source instead of URL arg as target
  * Print a little debug info when new carla-control connects
  * Fix strict build
  * audio/midi file plugins should alway list their file "presets"
  * Set audio and midi file path as used in MOD units
  * Fix macos-old build
  * Fix unused variable
  * Fix strict build
  * Put x64 lv2 plugins in bridge mode if needed (macOS only)
  * Remove plugins from macOS quarentine before running them
  * Only scan for relevant formats when using juce host
  * Automatically run VST2 intel/arm binaries on macOS as needed
  * Reduce amount of errors logged whe plugin bridge shm fails
  * Fix libmagic detection under macos-universal builds
  * Debug juce host plugin init
  * Fix drag&drop of VST2 plugins under macOS
  * Fix VST2 plugins nnot being loaded by juce host
  * Fix macOS dev environment
  * Try to fix macos-old build
  * Rework audio file plugin a bit, clean midi file ignore list
  * Document required MSYS2 fix
  * Fix LV2 worker event order
  * Make it no longer needed to do "make BUILDING_FOR_WINDOWS=true"
  * Catch patch:Set messages to update built-in parameters
  * Send lv2 parameter changes to UI; Don't reuse the same atom forge
  * Some little work for lv2 parameters in ui bridges, update modgui
  * Rework postponeRtEvent data to be union of structs
  * Fix compiler warning with qt4 theming
  * Fix wine32 build in Fedora
  * More tweaks as needed for macOS
  * Use newer cxfreeze on macOS universal builds
  * Tweaks in makefile and macOS script, in preparation for arm64/m1
  * Do not save/restore lv2 parameter-patch values, intercept restore
  * Fix building tests
  * Do not use fancy win32 dialog on mingw
  * Specify the new exports in the relevant file
  * Really fix symbols exports for host/native-plugin libs
  * Update to JUCE 6.0.4
  * Fix a few oddities in about dialog Closes #1272
  * Bump version to alpha2
  * Ammend last commit, use BUILD_BRIDGE_ALTERNATIVE_ARCH
  * Fix bridge build
  * Clear up which symbols are exposed in utils and standalone libs
  * Special macOS 10.12 treatment for Carla-Control as done for Carla
  * Fix GCC4 compatibility in clang
  * Fix strict build for >= or < qt 5.15
  * Final compatibility fixes
  * A few more GCC4 compat fixes
  * Fix juce_audio_basics for GCC4 compatibility
  * Fix a build warning against Qt 5.15
  * Fix juce_gui_basics to be GCC4 compatible
  * Set TARGET_MACHINE var in makefile, even if target OS already set Fixes #1266
  * Fix typo
  * Add i486 and i586 to archs supported by juce
  * Clean unzipfx of previous build Fixes #1267
  * Add extra dev libs in linux build, for vst3 support
  * Prevent assertion on getUniquePluginName() for short plugin names
  * export carla_get_native_plugins_data function
  * Fix previous commit
  * Fix macOS build
  * only try to use lv2 modgui under linux
  * test-load carla as lv2 plugin too
  * Fix memory leaks in LV2 stuff
  * test-load our vst plugin
  * Fix dropped symbols
  * Cleanup memory of the VST plugin
  * Remove "make test" target, this is for internal testing only
  * Load and test all internal plugins
  * Set NATIVE_PLUGIN_USES_CONTROL_VOLTAGE flag on C relevant plugins
  * Add a test for carla-host-plugin usage
  * Rework some symbol exports, resolving conflicts of standalone/utils
  * Fix header include test; Add a "make test" target
  * Fix CarlaNative.h for strict compiler mode
  * Remove a useless "<br>" in macOS README
  * Ignore "-psn_" prefixed CLI args on macOS
  * Allow to use dark theme/mode on newer macOS
  * Bump dev version for all the files
  * Reload plugin parameters after loading project in carla-plugin Fixes #1217
  * Allow to use canvas cut operations without prior window focus Fixes #1176
  * Ignore mouse wheel events when dragging canvas around
  * canvas: Only "drop" connection drag for mouse release of left button Fixes #1206
  * Implement custom plugin ui title on bridges Fixes #1219
  * Prevent assertion when jack driver not running in multi-client mode
  * Fix plugins having wrong id when switched around in patchbay mode Closes #1259
  * Better/faster detection for libmagic (when present)
  * interposer: add 'exit' (redirects to '_exit')
  * Match macos local env with build script
  * Fix strict build
  * Fixup macOS README, mentioning new plugin situation
  * Do not enable all 64 max buses for AU plugins
  * Tweaks for a proper macOS 10.12 build
  * Only set special plugin ui flags under windows, not wine/bridges
  * Fix warnings, print error code if win32 process start fails
  * Do not put plugin UIs on top in Windows; Fix window type Fixes #1116
  * Do not allow capture logs on windows, even if enabled
  * Give custom message in about page when liblo/osc is not enabled
  * Better compatibility with msys2
  * One less include to fix build on macos
  * Include utils code in carla-host-plugin library
  * Missing symbols in carla-host-plugin Fixes #1251
  * Add carla-host-plugin library, for usage in hosts
  * Packaging xycontroller in linux binary builds
  * Double-resolution tick for carla-lv2 plugin
  * Prevent bad vst host from giving carla-plugin invalid time values See #1236
  * Clear current project filename on engine stop Fixes #1243
  * Fix oddities with MIDI learn Closes #1248
  * Fix win32 packing
  * Fix xycontroller scene not sending all values
  * Generate macos app data for xycontroller-ui
  * Tweak windows packing script
  * patchcanvas: check validity of a few object's parentItems
  * Fix strict build
  * Build macos plugin packages
  * Use a dedicated folder for macos 10.12 builds
  * Alternative way to handle juce message thread in carla-plugin Fixes #1244 Fixes #1136
  * Bring juce UIs to front when shown
  * Re-link vst plugin objects when internal static libs change
  * Set develop version as 2.3.0-alpha1
  * Disable OSC by default on macos
  * Don't hide juce desktop window before deletion, fixes VST3 crashes
  * Forgot to revert a previous change; cleanup
  * Alternative, cleaner approach to JUCE run loop on carla-plugin Fixes #1238
  * Replace some XFlush calls with XSync
  * Carefully handle lv2 ui child window, fixes crash with some x42 uis Fixes #1128
  * Compress canvas clipboard image saving (as PNG) Closes #1078
  * Fix build with old compilers
  * Replace hacky midi-pattern temporary-note-flag with midi-queue
  * Finalize XY controller plugin
  * Add a simple midi queue class code
  * internal plugins: Allow to notify UI of MIDI events
  * Fix pipe UI message with empty value
  * XYController fixup, params work now
  * Fix build
  * Add WIP XYController UI
  * Add initial DSP code for xycontroller
  * Remove incomplete, unused patchcanvas c++ stuff
  * ScalableDial: Use PNG file for image 2
  * Add carla_fillFloatsWithSingleValue util function
  * Re-add dial_02 resources
  * Proper way to (un)define the value
  * Minor fix
  * Pass the extra wine include flags when building dgl
  * Another wine build fix
  * Add include paths used in wine-devel-dev package
  * Allow winehq-stable to build jackbridge
  * CI fixup before-install
  * CI: need i386 for linux main test too
  * CI: Need to install wine on main linux build too, checking bridges
  * CI fixup
  * More CI tweaks
  * Fix listing LV2 plugins on Windows
  * fluidsynth note after touch only for version >= 2
  * Alternative/better way to find all audio ports in juce plugins
  * Use focal
  * Wine packages in debian are weird..
  * Final CI fix
  * More CI tweaks
  * More CI tweaks
  * Use bionic for CI by default
  * Use fluidsynth v2 in CI builds
  * Note aftertouch is supported in fluidsynth now
  * Fix typo
  * midi pattern: prevent parameter changes when ui opens up
  * midi pattern: Do not delete notes when changing number of measures
  * midi pattern: quick&dirty note audition, fix octave offset
  * MIDI file/pattern: do not lose any RT events during save
  * Cleanup
  * midi pattern: Keep playback position while changing BPM Fixes #1210
  * Fix MIDI pattern missing notes at the edges, improve MIDI performance
  * Yet another fix for last translation commits
  * Build and installation of translation files
  * Fix last commit (extra unused import)
  * Search and load translation files at frontend startup
  * Dont try to build C++ frontend code, we will not use it after all
  * Select text in search entry also when focusing via shortcut
  * Initial code for mapped parameter flags
- Rebase carla-remove-pkgconf-rpath.patch.
* Wed Dec  9 2020 munix9@googlemail.com
- Fix Factory/Tumbleweed build with wine >= 6
  (probably related to boo#1179734)
* Sat Nov 21 2020 munix9@googlemail.com
- Update to version 2.2.0:
  * Fix GCC4 compatibility in clang
  * Fix strict build for >= or < qt 5.15
  * Final compatibility fixes
  * A few more GCC4 compat fixes
  * Fix juce_audio_basics for GCC4 compatibility
  * Fix a build warning against Qt 5.15
  * Fix juce_gui_basics to be GCC4 compatible
  * Use master branch in linux build script
  * Set TARGET_MACHINE var in makefile, even if target OS already set Fixes #1266
  * Fix typo
  * Add i486 and i586 to archs supported by juce
  * Clean unzipfx of previous build Fixes #1267
  * Add extra dev libs in linux build, for vst3 support
  * Update linux build package
  * Update linux build packages
  * Prevent assertion on getUniquePluginName() for short plugin names
  * Fix previous commit
  * only try to use lv2 modgui under linux
  * Fix memory leaks in LV2 stuff
  * Set NATIVE_PLUGIN_USES_CONTROL_VOLTAGE flag on C relevant plugins
  * Fix CarlaNative.h for strict compiler mode
  * Remove a useless "<br>" in macOS README
  * Ignore "-psn_" prefixed CLI args on macOS
  * Allow to use dark theme/mode on newer macOS
  * Drop the RC suffix
  * Reload plugin parameters after loading project in carla-plugin Fixes #1217
  * Allow to use canvas cut operations without prior window focus Fixes #1176
  * Ignore mouse wheel events when dragging canvas around
  * canvas: Only "drop" connection drag for mouse release of left button Fixes #1206
  * Implement custom plugin ui title on bridges Fixes #1219
  * Prevent assertion when jack driver not running in multi-client mode
  * Fix plugins having wrong id when switched around in patchbay mode Closes #1259
  * Better/faster detection for libmagic (when present)
  * Match macos local env with build script
  * Set 2.2-RC3 version for win/mac builds
  * Fix strict build
  * Fixup macOS README, mentioning new plugin situation
  * Set version as 2.2.0-RC3
  * Do not enable all 64 max buses for AU plugins
  * Tweaks for a proper macOS 10.12 build
  * Only set special plugin ui flags under windows, not wine/bridges
  * Fix warnings, print error code if win32 process start fails
  * Do not put plugin UIs on top in Windows; Fix window type Fixes #1116
  * Do not allow capture logs on windows, even if enabled
  * Give custom message in about page when liblo/osc is not enabled
  * Better compatibility with msys2
  * Bump linux script download
  * Packaging xycontroller in linux binary builds
  * Double-resolution tick for carla-lv2 plugin
  * Prevent bad vst host from giving carla-plugin invalid time values See #1236
  * Clear current project filename on engine stop Fixes #1243
  * Fix oddities with MIDI learn Closes #1248
  * Fix win32 packing
  * Fix xycontroller scene not sending all values
  * Generate macos app data for xycontroller-ui
  * Set version as 2.2.0-RC2 for packaging
  * Tweak windows packing script
  * patchcanvas: check validity of a few object's parentItems
  * Fix strict build
  * Alternative way to handle juce message thread in carla-plugin Fixes #1244 Fixes #1136
  * Bring juce UIs to front when shown
  * Re-link vst plugin objects when internal static libs change
  * Bump version to 2.1-RC2
  * Disable OSC by default on macos
  * Don't hide juce desktop window before deletion, fixes VST3 crashes
  * Forgot to revert a previous change; cleanup
  * Alternative, cleaner approach to JUCE run loop on carla-plugin Fixes #1238
  * Replace some XFlush calls with XSync
  * Carefully handle lv2 ui child window, fixes crash with some x42 uis Fixes #1128
  * Compress canvas clipboard image saving (as PNG) Closes #1078
  * Use a dedicated folder for macos 10.12 builds
  * Build macos plugin packages
  * Fix build with old compilers
  * Remove incomplete, unused patchcanvas c++ stuff
  * Replace hacky midi-pattern temporary-note-flag with midi-queue
  * Finalize XY controller plugin
  * XYController fixup, params work now
  * Add WIP XYController UI
  * Proper way to (un)define the value
  * Minor fix
  * Pass the extra wine include flags when building dgl
  * Another wine build fix
  * Add include paths used in wine-devel-dev package
  * Allow winehq-stable to build jackbridge
  * Alternative/better way to find all audio ports in juce plugins
  * Dont try to build C++ frontend code, we will not use it after all
  * Add a simple midi queue class code
  * internal plugins: Allow to notify UI of MIDI events
  * Fix pipe UI message with empty value
  * Fix build
  * Add initial DSP code for xycontroller
  * ScalableDial: Use PNG file for image 2
  * Add carla_fillFloatsWithSingleValue util function
  * Re-add dial_02 resources
  * Fix listing LV2 plugins on Windows
  * Select text in search entry also when focusing via shortcut
  * Fix typo
  * midi pattern: prevent parameter changes when ui opens up
  * midi pattern: Do not delete notes when changing number of measures
  * midi pattern: quick&dirty note audition, fix octave offset
  * MIDI file/pattern: do not lose any RT events during save
  * Cleanup
  * midi pattern: Keep playback position while changing BPM Fixes #1210
  * Fix MIDI pattern missing notes at the edges, improve MIDI performance
  * Set version for linux scripts too
  * Set 0 prefix for osx builds
  * Tweaks to windows build script
  * Fix regression, missing notes on new plugins
  * Version used by unzipfx needs final 0 suffix
  * Update linux scripts
  * A few more fixes for macos 10.8 build
  * Fix build with last commit
  * Fixup juce with macos 10.8, enable it again
  * Set version for osx builds, disable juce on 10.8 for now
  * Bump version on the windows scripts
  * Correct usage of LV2 options interface to change plugin block size
  * Add option to disabling sending notes to plugins (reverse on)
  * Fix MIDI file removing channel bit from 0-velocity note "on"s
  * Fixup RackListWidget::dragLeaveEvent
  * Fix strict build
  * Add unused PluginParameterData::getFinalValueWithMidiDelta()
  * Store the raw MIDI value in EngineControlEvent, for future use
  * Fix zero-velocity note-ons on MIDI files
  * carla-jack-multi should always show canvas Hiding for ladish is useless since ladish does not support multi-client anyway
  * Remove X-NSM-capable from main carla desktop file, forcing variants
  * Show canvas tab in jack-single or multi modes under NSM
  * Name the newly added desktop files
  * Bump version to 2.1.95 aka 2.2-RC1
  * Add desktop files with hidden status for all carla variants
  * Skip MIDI learn status when cloning or renaming plugin
  * Fix strict build
  * Increase lfo max value, so we can get real slow
  * Convert control parameter events into MIDI CCs to send to bridges
  * Implement MIDI CC and CV source parameter changes for bridges
  * Fix internal client build
  * Use a custom flag so our CV ports appear as CV right away
  * Do not give MIDI learn option for output or read-only parameters
  * Fix bridge build with previous commit
  * Initial implementation of MIDI learn (per plugin, not global)
  * Fix typo in MIDI CC list, leading to wrong Balance CC value
  * Show current mapped type+value directly together with parameter No more right clicking needed to find this info
  * Always use maximum amount of channels for VST2 plugins Fixes #1184 Fixes #1106
  * Don't use water namespace in CachedPlugins.cpp
  * Don't use water namespace in CarlaDssiUtils.cpp
  * Fix old macos build
  * Only load default state on LV2 plugins that request such feature
  * Copy lv2 state path contents when cloning plugin
  * Fix water File::copyDirectoryTo() to take into account symlinks
  * Better handling of LV2 temporary state, for clone and rename
  * Dont recreate symlinks; Add single quotes around debug paths
  * Symlink for LV2 abstract paths on request; Cleaner debug prints
  * More work for LV2 state path, symlinks and move/copy when needed
  * Check for state:threadSafeRestore on lv2 plugins; More debug paths
  * Keep current edit-dialog tab state while reloading parameters
  * carla-plugin: fix a few actions leading to inconsistent state
  * Skip inline redraw requests if engine mode has no patchbay
  * Some debug messages to help catch future issues
  * Fix recursion when using carla-patchbay under JACk with lv2 midnam
  * Fix default name for sfz with sfizz tricks
  * Ignore requests to hide UI if lv2 plugin uses files only
  * Add test code to replace sfz files with lv2 sfizz (disabled for now)
  * Add recently added jack-app MIDI support in client side, to stay in sync
  * Fix removing plugin in carla-rack plugin mode
  * Add a 12400x9600 canvas size Fixes #1197
  * Add debug prints regarding profile file/folder
  * carla-lv2: better handling of state make-path
  * Better handling of LV2 state paths, WIP
  * carla-plugin: force qt to use xcb backend if going to embed UI
  * Make lv2 state makePath return a unique path per plugin
  * carla-plugin: only request UI parameter changes if UI is visible
  * carla-plugin: define an lv2:Project
  * One more build fix
  * Fix build with previous commit
  * Use --whole-archive for internal static libs
  * Go back to previous way of specifying export symbols on macOS
  * Stop building carla-native-plugin test binary
  * Fix SF2 default polyphony Fixes #881
  * Add a few more details to lv2 plugin version, passes lv2lint
  * carla-plugin: Only export exactly the symbols that we need
  * Update juce stuff
  * Start experimenting with embed-ui API, for use in external tools
  * Clear canvas selection when deleting plugin, fixing assertions
  * Update juce sources to stable juce6 release (DISTRHO version)
  * Fix missing MIDI CC in jack-apps (was missing implementation)
  * Better support for NSM jack-apps: projects and non optional gui Fixes #1188
  * Add some safeties around invalid connection-id Need to investigate this more deeply later on
  * Allow all MIDI options in jack-apps
  * Interposer: also ignore XNextEvent for NSM
  * interposer: Better handling of destroyed windows, skip for some
  * Fix missing ports if client uuid fetch fails Error case was returning instead of continuing
  * Do not set client prefix from CLI if using NSM (let NSM handle it)
  * Fix rtaudio crash when there are no system input ports
  * Fix strict bridge build
  * Final tweaks for internal/external patchbay usage and projects
  * Skip graph CV source reconfigure when loading plugin state
  * Graph: Fix wrong buffer being cleared for unconnected cv ins
  * Tweaks to loading external patchbay data into internal one
  * Only care about client name prefix in multi-client mode
  * Add --cnprefix arg, for client name prefix; Set it also when needed
  * Don't rely on jack metadata callback being there for positions
  * Don't print message if client prefix conversion matches original
  * Be smarter about giving idle time during load, making it faster
  * Better error reporting regarding missing clients during load
  * Handle client name prefix during jack client rename
  * Convert from and to client name prefix as needed
  * Load canvas positions before loading connections
  * JACK: Be able to load canvas positions regardless of client prefix
  * Require that client name prefix include at least 1 dot
  * Reserve '/' character in plugin names (needed for client prefix)
  * Raise limit of plugins that can be loaded
  * Do not ask to quit carla if running under NSM show-gui server
  * One more pylint fix
  * Prevent visibility change events from messing with canvas pos
  * Fix frontend a bit for late messages just before closing
  * Fix strict build
  * Make sure to refresh canvas after project finishes loading
  * print warning when loading legacy canvas group pos file; fix lint
  * Always load patchbay connections when importing a carla project This ignores SM, as it should for this specific case
  * Load old canvas group pos file when project is imported (as needed)
  * Don't load old canvas json for 2.2 projects; Prevent load on close
  * Fix SFZ rescan adding all files again each time Fixes #906
  * Fix previous commit
  * sfzero: fix crash on multi-line c-style comments Fixes #1183
  * Implement LV2_STATE__freePath
  * Use state free-path in carla-lv2 whenever possible
  * Update pre-included lv2 state.h header
  * Nicely stop async event loop for modguis
  * Fix build without liblo
  * Fix modguis for carla host changes and new tornado
  * Allow to change plugin window title dynamically
  * Fully implement carla_set_custom_ui_title
  * Make settings tab-like section slightly bigger
  * Split/Join groups automatically based on host messages Fixes #1177
  * Fix callback recursion on carla-plugin patchbay group moves
  * Fix bridges build yet yet again
  * Fix bridges build once again
  * Make the previous changes backwards compatible
  * Use jack client prefic when renaming clients too
  * Allow to set custom prefix for jack clients, use it under NSM
  * Fix bridges build
  * carla-lv2: First attempt at getting project dir from host
  * Better handle lv2 map/make path, now based on project dir
  * Fix carla-plugin never deleting plugins
  * Add API to know current project folder
  * Better handle case of JACK server stop (or killed)
  * Fix useless assertion when deactivating client for final cleanup
  * Run plugin idle() ourselves when engine is not running
  * plugin-bridge: give host idle time while waiting for parameter text
  * plugin-bridge: send back empty/null responses when plugin disabled
  * GUI: Don't check for engine running before stop action
  * NSM/jack-app: Catch "/nsm/server/stop" and use it to hide GUI
  * Support custom "/nsm/gui/client/save" for jack-apps
  * NSM: use server-control instead of server_control
  * libjack: an attempt to make all needed symbols visible
  * Make add-jack interposer work for builds without X11
  * Always flush console output if debug on
  * Fix false positives regarding jack meta-data and internal clients
  * Don't use newlocale stuff on macOS Fixes #1174
  * JACK: prevent recursion on patchbay group position changes
  * Fix windows build (typo on previous commits)
  * libjack: implement type filter in jack_get_ports
  * libjack: fix under clang and maybe other systems
  * ChildProcess: use vfork, kill child process when parent dies
  * Cleanup ChildProcess code
  * Fix a build warning
  * Handle case of NSM server not supporting optional-gui
  * jack-as-plugin: send gui show/hide depending on app's NSM support
  * Fix strict build warnings against clang
  * libjack: clean memory correctly in case of error
  * Ignore one assertion regarding JACK meta-data (false positive)
  * Fix strict build
  * Fix for some missing scalable icons
  * libjack: a few more fixes (when carla is not running)
  * Fix for dumb compilers
  * Remove pipe utils hack for haiku, no longer needed
  * Fix strict build
  * More libjack work, basic support for UUIDs
  * Fix jack-as-plugin flags for debugging
  * Correct and modify a few debug messages
  * Fix carla-rack under NSM
  * libjack: Implement client name uuid stuff
  * Fix crash with libjack port search requests
  * Fix typo
  * Manage visibility state for NSM, starts hidden
  * Implement NSM :optional-gui:
  * Fix %% issue in about dialog Closes #1169
  * Fix unzipfx tmppath suffix
  * Fix VST plugin Closes #1170
  * Fix build under haiku
  * Being nitpicky on whitespace
  * Fix external-ui internal plugins with the latest changes
  * Fix carla-plugin Closes #1166
  * Fix CI
  * More pylint corrections
  * Rename cursors; Cleanup CanvasPreviewFrame class
  * Fixup for pylint
  * Use base for CI scripts
  * pylint3 needs at least 18.04
  * Start checking python code with pylint, adjust some already
  * Fixup the assertion added in the previous commit
  * Fix usage without jack meta-data support
  * Fix JACK internal client build
  * Adjust the (incomplete) C++ port to latest API changes
  * Fix OSC handling method check for long strings
  * Fixup calf skin
  * Fixup ScalableDial to be compatible with old pixmaps
  * Make LEDButton compatible with old pixmaps
  * Make ScalableButton compatible with old pixmaps
  * Fix up new scripts to work system-wide, and install them by default
  * Add script to test carla-osc usage locally
  * Add script used to test carla-plugin as standalone
  * New internal CLI arg "--osc-gui="
  * Fix carla-control not handling CLI arg for custom address
  * Fix carla-control adding more than 1 plugin
  * Fix a couple of issues with carla-plugin
  * Avoid comparing shared_ptr directly to nullptr
  * Fix bridge build
  * Fix typo
  * Backwards compatible std::shared_ptr
  * Fix build, partially
  * Improve performance of inline display rendering
  * patchcanvas: Fix some groupos with inline display becoming too small
  * patchcanvas: Fix ports text width calculation
  * Change the way plugins are deleted, ensure they are not being used
  * Fully Scalable UI Part 2
  * Fix wrong custom dial arcs value and add fix from #1126
  * Fully Scalable UI Part 1
  * Fix wrong assertion with size 1 MIDI messages in carla-patchbay Closes #1099
  * Add missing QPainterPath include
  * VST2: Fix creation of a rack when one of the parameters is a NaN
  * Add new files from juce
  * Update JUCE
  * Fix strict build
  * Fix build
  * Check for updated program names during audioMasterUpdateDisplay
  * Fix bridged discovery build
  * Add action to copy canvas as image to clipboard
  * Tweak code for canvas group positions See #1139
  * Fix build in some systems
  * Tweak previous commit to work under plugin bridges too
  * Try to load vst2 plugin again if first time plugin blows up
  * Fix for vst2 plugins that crash on init
  * Force discovery to be in "C" (english) so we can parse errors
  * Ignore errors from non-native vst3 files
  * Use newlocale methods in CarlaScopedLocale to be thread-safe
  * Pass DLS/GIG files into fluidsynth if version is recent enough
  * Fixup icons Closes #972
  * Some attention to inline display
  * Protect *all* metadata access, even in bridge mode
  * Protect jack metadata usage with a mutex; other position fixes
  * Change an error message
  * Protect backend from a few late calls after engine close request
  * Add new CARLA_CUSTOM_SAFE_ASSERT
  * Fix a const variable
  * fix incorrect base conversion for midi CC numbers
  * Make pixmapkeyboard right-click menu a bit better
  * Typo
  * Manually create image save dialog so we can tweak values Fixes #597
  * Make canvas ports and groups ignore middle mouse clicks Fixes #1085
  * Ignore Carla-VST resize requests if not using embed gui
  * Set correct Carla-VST UI size based on scale factor Closes #1057
  * Fix for dumb compilers
  * Add 2x and 4x zoom save image actions, compress output
  * Try to fix old gcc build
  * Use CARLA_CATCH_UNWIND in the base utils
  * Small fixups for jack engine
  * Save pluginId as part of the patchbay positions
  * Fix for old compilers
  * Fix bridges build
  * Fix small oddities in internal patchbay mode; Cleanup
  * Bump version a tiny bit
  * Allow drag&drop in canvas area
  * Fix canvas groups getting stuck out of screen with last commits
  * Listen to canvas group position changes over JACK metadata and OSC
  * Add jackbridge_uuid_unparse
  * First go at backend-side canvas positions; Safer jack callbacks
  * Fix build with EXTERNAL_PLUGINS=false
  * Fixup macOS 10.12 packaging
  * Disable patchcanvas basic eye-candy (box shadow) causes crashes
  * Fix for CI
  * Fix ttl not generated in Windows builds
  * Fix an hardcoded value in waitForAsyncObject
  * Fix win32 build using old win64 mingw
  * Fix missing ALSA engine driver support in Linux builds Closes #1115
  * Add "Find plugin in patchbay" right-click option
  * Only build juce for certain archs; Report if using vst3 support
  * Update JUCE
  * Fix strict build
  * Fix for some juce-based plugins having 0 audio ports Closes #1084
  * Adjust UI a bit for logs tab, also I was wrong :P
  * Workaround build issue with old 32bit mingw Sort of testing
  * Add Save, Clear and toggle autoscroll to the Logs tab (#1129)
  * Fix static CarlaParameterInfo cleanup Fixes #1105
  * Fix LV2 UI not showing up if host supports touch Fixes #1104
  * Initial go at category filters
  * Fix JUCE compilation on Linux with DEBUG=true (#1125)
  * Allow to drag&drop vst3 folders for any OS
  * Inform VST2 and JUCE plugins about UI scale factor
  * discovery: print category for LADSPA and DSSI (based on name)
  * Fix build without juce
  * VST discovery: assume midi inputs = 1 if plugin is synth
  * Fix typo
  * Use new JUCE init stuff for discovery, set category for JUCE format
  * Move standalone juce init/idle/cleanup to new file, expose an API
  * Use "-Wa,-mbig-obj" for juce debug builds, cleanup Closes #1122
  * Use -fno-common in build flags so we can early catch gcc-10 issues
  * Update Travis syntax (#1114)
  * Xcursor not needed as library, only the headers
  * xcursor is needed for juce
  * fix rpath specification in pc files to use a csv instead of equals sign (fixes errors when linking on macos)
  * Yet another CI fix
  * Initializing juce is not needed for carla-vst linux build
  * Fix linux-juce-strict CI
  * CI tweaks
  * Revert a few things regarding CarlaProcessUtils
  * Final build fix
  * I want emails
  * Fix Windows build
  * Fixup for CI
  * Add personal script to copy juce stuff
  * Bring back just vst2 support
  * Sync JUCE with DISTRHO, move mingw-std-threads into modules/
  * Use ScopedAbortCatcher to avoid crashing with u-he vst3 plugins
  * Split CarlaProcessUtils in hpp/cpp, add ScopedAbortCatcher
  * Use JUCE by default on linux if supported; Cleanup config a bit
  * Quick way to get mingw to build
  * Do not use JUCE for vst2 handling, for now
  * Final details for scanning etc vst3 linux stuff Closes #1094
  * Fixup build with new juce
  * Fixup and cleanup carla-discovery for new juce, also vst3 linux
  * Enable juce vst3 support under linux, and disable vst2 (internal)
  * Tweak build flags for new juce
  * Actually update vst3sdk
  * Build juce_gui_extra under linux
  * Update vst3sdk and juce
  * Fix previous commit
  * Replace wine function check for Z:\usr\ folder check
  * Fixup windows definition files and CI
  * Do not use wine for native win32 builds
  * Specify windows library definitions for carla plugins
  * Fix list of exported symbols for libcarla-native-plugin.dylib
  * Allow to customize pkg-config
  * WIP stuff
  * discovery: print category as a string, for internal plugins too
  * discovery: print category for vst plugins (#1073)
  * Fix strict build
  * Only standalone should call carla_engine_idle
  * Allow carla-plugin to have full access to Host API
  * Fix build
  * Host API calls now require handle as first argument
* Mon Sep 28 2020 Dave Plater <davejplater@gmail.com>
- Enabled liblo for Tumbleweed.
* Sat Sep 26 2020 Dave Plater <davejplater@gmail.com>
- Disable liblo until python-pyliblo is on the way to Tumbleweed
  see boo#1177001
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Thu Jun 25 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Link .exe files with --no-insert-timestamp option
  to make package build reproducible (boo#1041534)
* Fri Jun 12 2020 davejplater@gmail.com
- Update to version 2.1.1 and remove incorporated patches:
  0001-Fix-a-const-variable.patch and
  0001-Add-missing-QPainterPath-include.patch
- Upstream changes:
  * Use CARLA_CATCH_UNWIND in the base utils
  * Fix build with EXTERNAL_PLUGINS=false
  * Bump version to 2.1.1
  * Fixup macOS 10.12 packaging
  * Fix carla-control not handling CLI arg for custom address
  * Fix carla-control adding more than 1 plugin
  * Fix a couple of issues with carla-plugin
  * Improve performance of inline display rendering
  * patchcanvas: Fix ports text width calculation
  * Fix wrong assertion with size 1 MIDI messages in JACK code path
* Tue Jun  2 2020 Dave Plater <davejplater@gmail.com>
- Fix factory build with patch from git:
  0001-Add-missing-QPainterPath-include.patch
- Added patch from git:
  0001-Fix-a-const-variable.patch
* Thu May 28 2020 Dave Plater <davejplater@gmail.com>
- Use service file to remove data/windows directory from tarball.
* Wed Apr 22 2020 Dave Plater <davejplater@gmail.com>
- Update license field and added bsd-2-clause.txt
* Thu Apr 16 2020 Edgar Aichinger <edogawa@aon.at>
- update to version 2.1 final
- update carla-remove-pkgconf-rpath.patch for version 2.1
- remove carla-link-mingw.patch (solved upstream)
* Sat Apr 11 2020 Dave Plater <davejplater@gmail.com>
- Update to git snapshot version 2.0.0+git20200331 aka v2.1-rc2.
- Build posix32, wine32 and win32 plugins and plugin utils for
  Tumbleweed see boo#1168659
- Added carla-link-mingw.patch to fix win32 build.
- Upstream changes:
  * bigmeter plugin does not need fixed buffers fixes #1050
  * Can always drag&drop vst3 files because of bridges
  * Increase default size of plugin RT data pool
  * Fix missing idle in native plugins, leading to no post rt events
  * Fix jack metadata usage for multiple carla instances
  * Focus bridged UI when shown #954
* Fri Apr  3 2020 Dave Plater <davejplater@gmail.com>
- Add %%post message carla-warning.
* Fri Mar 27 2020 Dave Plater <davejplater@gmail.com>
- Update to git snapshot version 2.0.0+git20200310 and remove
  incorporated patch:
  0001-Place-Qt-stuff-outside-of-custom-namespace.patch
- Added carla-remove-pkgconf-rpath.patch to remove rpath in pc files
- Rebased carla-systemlibs.patch
- Fix Factory build.
- Many upstream fixes and improvements
* Mon Dec  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Place-Qt-stuff-outside-of-custom-namespace.patch to fix
  build with GCC9.
- Run spec-cleaner
* Tue Apr 30 2019 Edgar Aichinger <edogawa@aon.at>
- update to 2.0.0
* Mon Apr  1 2019 Christophe Giboudeaux <christophe@krop.fr>
- Remove the Qt4 support. Qt4 will be removed from factory soon.
* Fri Mar 15 2019 Edgar Aichinger <edogawa@aon.at>
- Reverted %%description to previous state
* Mon Mar 11 2019 Edgar Aichinger <edogawa@aon.at>
- update to 2.0-RC4 (aka 1.9.14)
* Tue Nov 27 2018 Edgar Aichinger <edogawa@aon.at>
- spec: update application URL
- spec, package meta: update description
* Wed Nov 14 2018 Edgar Aichinger <edogawa@aon.at>
- spec: define provides-exclude for internal libjack.so.0
* Mon Nov 12 2018 Edgar Aichinger <edogawa@aon.at>
- updated carla-systemlibs.patch to current sources
- removed carla.libjack-soversion.patch (workaround for a past link problem, not needed anymore)
* Thu Nov  8 2018 Edgar Aichinger <edogawa@aon.at>
- updated to 2.0-RC2 (aka 1.9.12)
  * reenabled fluidsynth support
* Thu Sep 27 2018 Edgar Aichinger <edogawa@aon.at>
- updated to 2.0-RC1 (aka 1.9.11)
  * removed fluidsynth support temporarily (API changed)
  * removed carla.libjack-soversion.patch and carla-systemlibs.patch
    temporarily, will update these as needed in near future
* Thu Aug  9 2018 edogawa@aon.at
- fiddled with _service to include the git submodule ("native external plugins")
- major spec file cleanup (remove rdflib bcond, adjust BuildRequires to utilize pkgconfig () etc.
- now carla's own GUI uses Qt5 instead of Qt4
* Sat Aug  4 2018 opensuse-packaging@opensuse.org
- Update to version 1.9.9+git20180721.c03571a9:
  * Forgot to bump version in a script
  * Bump version to beta7
  * Update submodule
  * Don't show option regarding qutting carla in carla plugin settings
  * Don't show quit confirmation dialog when running as plugin
  * More aggressive hacks around linuxsampler
  * Fix spelling
  * Fix SharedResourcePointer includes
  * Allow CarlaMutex to be constructed on the heap
  * Minor compiler warning fix
  + Add confirmation dialog for quitting Carla
  + Add confirmation dialog for "Remove All" and "New File" actions
  + Add internal MIDI Channel A/B plugin
  + Add semitones parameter to internal midi-transpose plugin
  + Implement move up/down plugins in rack (right-click menu)
  + Implement LV2 UI port notifications to feedback messages to UI
  + Implement more libjack stubs, Catia now loads inside Carla :)
  + Transport controls are now considered stable and always enabled, no longer in experimental settings
  + Disable ableton-link and audio kits search UI elements if not built/enabled
  + Do not capture logs if running in nogui mode
  + Do not use or check for kVstParameterUsesIntegerMinMax VST property
  + Do not lockup on close in case audio driver stops working
  + Export LV2 window is now a simple combo-box, making it more usable
  + Save plugin author name in exported LV2 plugin
  + Increase polling rate for non-gui mode (30 Hz), fixes slow OSC handling
  + Fix mouse position offset of Carla-embed mouse events
  + Fix processing of internal plugins with multi MIDI inputs
  + Fix crash when closing a session containing bridges with Ctrl+C
  + Fix patchbay/graph to work with variable buffer sizes
  + Fix some issues regarding integer parameter control
  + Fix controlling logarithmic parameters with MIDI CC
  + Fix "MIDI CC 0x01" not selectable in some systems
  + Fix loading of VST plugin parameters and LV2 state for plugin bridges
  + Fix carla-single usage under ladish
  + Fix file dialog filter of the internal MIDI file plugin
* Wed Feb 28 2018 dimstar@opensuse.org
- Drop liblinuxsampler-devel BuildRequires: linuxsamplerate was
  identified to have an exception clause on their 'gpl license'
  that makes it non-free (non-commercial exception).
* Mon Nov 20 2017 edogawa@aon.at
- added carla.libjack-soversion.patch (removes soversion from private libjack.so.0)
- removed unneeded explicit BuildRequires: jack-devel,
* Wed Nov 15 2017 edogawa@aon.at
- Update to version 1.9.7+git20171111.5b97ec1e
  * removed carla-buildcompare.patch, not needed anymore
  * updated carla-systemlibs.patch so it applies to current source
* Fri Aug 11 2017 edogawa@aon.at
- remove carla-gcc7.patch - being a failed attempt to fix 32bit compilation
* Thu Aug 10 2017 olaf@aepfle.de
- Wipe __DATE__/__TIME with carla-buildcompare.patch
- Fix build with carla-gcc7.patch
- Use system flac/vorbis/ogg with carla-systemlibs.patch
- ExclusiveArch x86_64 until i386 is fixed
* Fri Jul  7 2017 9@cirno.systems
- Add missing runtime dependency on PyQt4
* Fri Jun 16 2017 olaf@aepfle.de
- Remove override of pyuic4
* Tue Mar 28 2017 olaf@aepfle.de
- ExclusiveArch Intel
* Fri Feb 24 2017 opensuse-packaging@opensuse.org
- Update to version 1.9.7+git20170124.9ff1711b:
  * Remove (unused) usage of pyqtWrapperType
* Sun Feb  5 2017 jengelh@inai.de
- Trim irrelevant parts from description
* Tue Jan 17 2017 olaf@aepfle.de
- change mode from localonly to disabled in _service
- fix build on nonx86
* Mon Aug 15 2016 olaf@aepfle.de
- Update to 1.9.6+git20160801.e07f144
  + Fix build with gcc6
* Mon Mar  7 2016 edogawa@aon.at
- Update to version 1.9.6+git20160305.f8933f9:
  + Update zynaddsubfx
  + Add carla-patchbay-vst 16 channel variant
  + Give a name to the patchbay internal ports; Cleanup
  + Add ZebraHZ to the list of u-he workarounds
  + Try to avoid denormals for plugin bridges
  + Fix build
  + Update juce
  + Fix for nasty&weird mingw compiler error
  + Update zynaddsubfx Fixes #368
  + Remove mverb as internal plugin Having GPLv3 as license makes carla itself GPLv3. Let's keep Carla at GPLv2+ please :) (a single simple plugin is not worth the "upgrade")
  + Update DPF based modules
  + Update DPF based plugins (only minor misc changes)
* Sat Jan 30 2016 edogawa@aon.at
- some more spec file cleanup
  + removed unneeded buildreqs and reordered the remaining ones for readability
* Sat Jan 30 2016 rpm@fthiessen.de
- Added bcond (conditional build) for python3-qt4/5 and rdflib
  + Fixes build with openSUSE 13.1 and openSUSE Leap 42.1
- General spec file cleanup
- Update to version 1.9.6+git20160124.544f0fc:
  + Implement discovery for ':all' used in last commit
  + Some minor changes needed for bridged AU plugins
  + Don't use unneeded functions in discovery, fixes windows build
  + Ignore uniqueIds for LV2 plugins
  + Use plugin audio port names in bridge mode Fixes #344
  + Avoid calling jack1's bad set_thread_init_callback Fixes #337
  + Increase the maximum allowed per-atom size
  + Don't write atom to ringbuffer after it fails the initial data
  + Find plugin binary when saved filename doesn't exist
* Tue Jan 12 2016 edogawa@aon.at
- updated to version 1.9.6.git.2016.01.02
* Tue Mar 31 2015 edogawa@aon.at
- updated to 2.0-beta4
* Sat Jan 10 2015 edogawa@aon.at
- initial package (version 2.0-beta3)
